#include <GL/glut.h>    // Header File For The GLUT Library 
#include <GL/gl.h>	// Header File For The OpenGL32 Library
#include <GL/glu.h>	// Header File For The GLu32 Library

#include "Globals.h"
#include "Interface.h"
#include "Input.h"
#include "uObject.h"
#include "Explosions.h"

//int window; 


void InitGL(int Width, int Height)	        // We call this right after our OpenGL window is created.
{
	glClearColor(0.2f, 0.2f, 0.3f, 0.0f);		// This Will Clear The Background Color To Black
	glClearDepth(1.0);				// Enables Clearing Of The Depth Buffer
	glDepthFunc(GL_LESS);			        // The Type Of Depth Test To Do
	glEnable(GL_DEPTH_TEST);		        // Enables Depth Testing
	glShadeModel(GL_SMOOTH);			// Enables Smooth Color Shading
	
	glMatrixMode(GL_PROJECTION);
	glLoadIdentity();				// Reset The Projection Matrix
	
	gluPerspective(45.0f,(GLfloat)Width/(GLfloat)Height,0.1f,100.0f);	
	
	glMatrixMode(GL_MODELVIEW);
	glutSetCursor(GLUT_CURSOR_NONE);
}


void ReSizeGLScene(int Width, int Height)
{
	if (Height==0)				// Prevent A Divide By Zero If The Window Is Too Small
	Height=1;
	
	glViewport(0, 0, Width, Height);		
	
	glMatrixMode(GL_PROJECTION);
	glLoadIdentity();
	
	gluPerspective(45.0f,(GLfloat)Width/(GLfloat)Height,0.1f,100.0f);
	glMatrixMode(GL_MODELVIEW);
}

void DrawGLScene()
{
	bool   gp;						// G Pressed? ( New )
	GLuint filter;						// Which Filter To Use
	GLuint fogMode[]= { GL_EXP, GL_EXP2, GL_LINEAR };	// Storage For Three Types Of Fog
	GLuint fogfilter= 0;					// Which Fog To Use
	GLfloat fogColor[4]= {0.7f, 0.7f, 0.8f, 0.5f};	
	extern float camX, camY, camZ;
	glClear(GL_DEPTH_BUFFER_BIT | GL_COLOR_BUFFER_BIT);	// Clear The Screen And The Depth Buffer
	glLoadIdentity();				// Reset The View
	gluLookAt(camX,camY,camZ,0.0,0.0,0.0,0.0,1.0,0.0);
	
	glFogi(GL_FOG_MODE, fogMode[2]);		// Fog Mode
	glFogfv(GL_FOG_COLOR, fogColor);			// Set Fog Color
	glFogf(GL_FOG_DENSITY, 0.5f);				// How Dense Will The Fog Be
	glHint(GL_FOG_HINT, GL_DONT_CARE);			// Fog Hint Value
	glFogf(GL_FOG_START, 60.0f);				// Fog Start Depth
	glFogf(GL_FOG_END, 100.0f);				// Fog End Depth
	glEnable(GL_FOG);	
	
	glEnable(GL_LINE_SMOOTH);
	glEnable(GL_BLEND);
	glBlendFunc(GL_SRC_ALPHA,GL_ONE_MINUS_SRC_ALPHA);
	glEnable(GL_DEPTH_TEST);
	//glTranslatef(0.0f,0.0f,-6.0f);		// Move Left 1.5 Units And Into The Screen 6.0
	glShadeModel(GL_SMOOTH);
	glEnable(GL_LIGHTING);
	GLfloat LightAmbient[]= { 0.5f, 0.5f, 0.5f, 1.0f };
	GLfloat LightDiffuse[]= { 1.0f, 1.0f, 1.0f, 1.0f };
	GLfloat LightPosition[]= { 0.0f,1.0f, 0.0f, 1.0f };
	glLightfv(GL_LIGHT1, GL_AMBIENT, LightAmbient);
	glLightfv(GL_LIGHT1, GL_DIFFUSE, LightDiffuse);
	glLightfv(GL_LIGHT1, GL_POSITION,LightPosition);
	glEnable(GL_LIGHT1);	
	//glutSolidSphere(1,10,10);
	drawInterface();
	glPushMatrix();
		//glColor3f(0.0,0.0,0.0);
			drawObjects();
			glDisable(GL_LIGHTING);
			drawMovementPath();
		glEnable(GL_LIGHTING);
	glPopMatrix();
	updateExplosions();
	glPushMatrix();
		//glColor3f(0.0,0.0,0.0);
			drawExplosions();
	glPopMatrix();
	
	// swap the buffers to display, since double buffering is used.
	glutSwapBuffers();
	glDisable(GL_LIGHTING);
}

void drawSaveScene()
{
	glClearColor(0.8f, 0.8f, 0.8f, 0.0f);
	extern float camX, camY, camZ;
	glClear(GL_DEPTH_BUFFER_BIT | GL_COLOR_BUFFER_BIT);	// Clear The Screen And The Depth Buffer
	glClearColor(0.2f, 0.2f, 0.3f, 0.0f);
	glLoadIdentity();				// Reset The View
	gluLookAt(camX,camY,camZ,0.0,0.0,0.0,0.0,1.0,0.0);
	glEnable(GL_LINE_SMOOTH);
	glEnable(GL_BLEND);
	glBlendFunc(GL_SRC_ALPHA,GL_ONE_MINUS_SRC_ALPHA);
	glEnable(GL_DEPTH_TEST);
	//glTranslatef(0.0f,0.0f,-6.0f);		// Move Left 1.5 Units And Into The Screen 6.0
	glShadeModel(GL_SMOOTH);
	glEnable(GL_LIGHTING);
	GLfloat LightAmbient[]= { 0.5f, 0.5f, 0.5f, 1.0f };
	GLfloat LightDiffuse[]= { 1.0f, 1.0f, 1.0f, 1.0f };
	GLfloat LightPosition[]= { 0.0f, -40.0f, 40.0f, 1.0f };
	glLightfv(GL_LIGHT1, GL_AMBIENT, LightAmbient);
	glLightfv(GL_LIGHT1, GL_DIFFUSE, LightDiffuse);
	glLightfv(GL_LIGHT1, GL_POSITION,LightPosition);
	glEnable(GL_LIGHT1);	
	//glutSolidSphere(1,10,10);
	//drawInterface();
	glPushMatrix();
		//glColor3f(0.0,0.0,0.0);
			drawObjects();
			glDisable(GL_LIGHTING);
			//drawMovementPath();
		glEnable(GL_LIGHTING);
	glPopMatrix();
	glPushMatrix();
		//glColor3f(0.0,0.0,0.0);
			drawExplosions();
	glPopMatrix();
	// swap the buffers to display, since double buffering is used.
	glutSwapBuffers();
	glDisable(GL_LIGHTING);	
}
